function demo_mdds2d
%demo_mdds2d --> Demonstration of B-net computation, exact evaluation and
%                visualization of bivariate three-direction Box-splines.
%
%<See Also>
%  demo_mdds3d --> Demonstration of B-net computation, exact evaluation and
%                 visualization of trivariate four-direction Box-splines.

%<Reference>
%  [1] G. Casciola, E. Franchini, L. Romani, "The mixed directional 
%      difference-summation algorithm for generating the Bezier net of a 
%      trivariate four-direction Box-spline"
%      Numerical Algorithms 43 (2006), pp. 75-98.
%
%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

clc

disp('|---------------------------------------------------------------------|');
disp('| demo_mdds2d                                                         |');
disp('| This function provides three examples to demonstrate the use of the |');
disp('| functions bnet_mdds(), pointeval_mdds2d(), visual_mdds2d() which    |');
disp('| allow respectively the Bezier net computation, the stable and       |');
disp('| efficient evaluation in an arbitrary set of 2D points, and the      |');
disp('| visualization of the surface graph and the associated B-net of a    |'); 
disp('| given bivariate three-direction Box-spline.                         |');
disp('|---------------------------------------------------------------------|');

disp(' ');
disp('The first example uses the quadratic Box-spline M_211.');
disp(' ');
disp('The multiple occurrence of identical directions e_1=[1 0]'', e_2=[0 1]'','); 
disp('e_12=[1 1]'' is logged in a vector nu holding the number of times'); 
disp('each direction is repeated:');
disp(' ');
nu=[2 1 1];
fprintf('nu= [%d %d %d]\n\n',nu);
fprintf('Press any key to continue.\n\n');
pause  

disp('1. Computation of the Bezier net coefficients of the quadratic'); 
disp('   Box-spline M_211');
A1=bnet_mdds(nu);
disp(' ');
disp('The matrix you see right now is exactly the bi-dimensional array'); 
disp('containing the Bezier net coefficients of the quadratic Box-spline');
fprintf('M_211 (save for the factor 1/m!, where m=%d is degree(M_211)):\n\n',...
    sum(nu)-2);
disp(A1);
fprintf('\nPress any key to continue.\n\n');
pause  

disp('2. Evaluation of the quadratic Box-spline M_211');
disp(' ');
disp('The evaluation algorithm can be applied to an arbitrary set of sample');
disp('2D points inside the Box-spline support. Here we evaluate the quadratic'); 
disp('Box-spline M_211 in a given arbitrary 2D point P:');
disp(' ');
P=[2 1];
fprintf('P=[%2.1f %2.1f]\n',P);
point_value=pointeval_mdds2d(nu,P);
fprintf('point_value=%6.4f\n\n',point_value);
fprintf('Press any key to continue.\n\n');
pause 

disp('3. Visualization of the quadratic Box-spline M_211');
disp(' ');
disp('The figures you see right now are respectively the graph of the'); 
disp('Box-spline surface M_211 and the associated Bezier net');
visual_mdds2d(nu,3,10);
fprintf('\nPress any key to see next example.\n\n');
pause  

clc

disp('-----------------------------------------------------------------');
disp(' ');
disp('The second example uses the quartic Box-spline M_222');
disp('associated with the following multiplicities vector nu:');
disp(' ');
nu=[2 2 2];
fprintf('nu= [%d %d %d]\n\n',nu);
fprintf('Press any key to continue.\n\n');
pause 

disp('1. Computation of the Bezier net coefficients of the quartic'); 
disp('   Box-spline M_222');
A1=bnet_mdds(nu);
disp(' ');
disp('The matrix you see right now is exactly the bi-dimensional array'); 
disp('containing the Bezier net coefficients of the quartic Box-spline');
fprintf('M_222 (save for the factor 1/m!, where m=%d is degree(M_222)):\n\n', ...
    sum(nu)-2);
disp(A1);
fprintf('\nPress any key to continue.\n\n');
pause 

disp('2. Evaluation of the quartic Box-spline M_222 in a given arbitrary'); 
disp('   2D point P');
disp(' ');
P=[2 2];
fprintf('P=[%2.1f %2.1f]\n',P);
point_value=pointeval_mdds2d(nu,P);
fprintf('point_value=%6.4f\n\n',point_value);
fprintf('Press any key to continue.\n\n');
pause 

disp('3. Visualization of the quartic Box-spline M_222');
disp(' ');
disp('The figures you see right now are respectively the graph of the '); 
disp('Box-spline surface M_222 and the associated Bezier net');
disp('(see Fig.15 in [1])');
visual_mdds2d(nu,3,10);
fprintf('\nPress any key to see next example.\n\n');
pause 

clc

disp('---------------------------------------------------------------');
disp(' ');
disp('The last example uses the quintic Box-spline M_322');
disp('associated with the following multiplicities vector nu:');
disp(' ');
nu=[3 2 2];
fprintf('nu= [%d %d %d]\n\n',nu);
fprintf('Press any key to continue.\n\n');
pause 

disp('1. Computation of the Bezier net coefficients of the quintic'); 
disp('   Box-spline M_322');
A2=bnet_mdds(nu);
disp(' ');
disp('The matrix you see right now is exactly the bi-dimensional array'); 
disp('containing the Bezier net coefficients of the quintic Box-spline');
fprintf('M_322 (save for the factor 1/m!, where m=%d is degree(M_322)):\n\n', ...
    sum(nu)-2);
disp(A2);
fprintf('\nPress any key to continue.\n\n');
pause 

disp('2. Evaluation of the quintic Box-spline M_322 in a given arbitrary'); 
disp('   2D point P');
disp(' ');
P=[3 2];
fprintf('P=[%2.1f %2.1f]\n',P);
point_value=pointeval_mdds2d(nu,P);
fprintf('point_value=%6.4f\n\n',point_value);
fprintf('Press any key to continue.\n\n');
pause 

disp('3. Visualization of the quintic Box-spline M_322');
disp(' ');
disp('The figures you see right now are respectively the graph of the'); 
disp('Box-spline surface M_322 and the associated Bezier net');
visual_mdds2d(nu,3,10);
fprintf('\nPress any key to close all.\n');
pause
close all
clc
