function c = dupl_mdds(b,m,dir,m1)
%dupl_mdds --> Duplication of some elements of the vector b which 
%              contains the coefficients of the main direction.
%
%<Synopsis>
%  c = dupl_mdds(b,m,dir)
%  c = dupl_mdds(b,m,dir,m1)
%
%<Description>
%  Both in bivariate and trivariate cases, the computation of the 
%  mixed directions in R requires to generate a vector containing 
%  the coefficients of the main direction duplicated.
%
%<Input Parameters>
%   b   --> vector with the coefficients of the main direction
%   m   --> Box-spline degree
%   dir --> parameter that identifies the direction along which
%           we are operating
%           - In the bivariate case:
%              dir=1 if operating direction=e_1
%              dir=2 if operating direction=e_2
%              dir=3 if operating direction=e_12
%           - In the trivariate case:
%              dir=1 if operating direction=(e_1 | e_2)
%              dir=2 if operating direction=e_3
%              dir=3 if operating direction=e_123
%   m1  --> multiplicity of operating direction 
%           - In the bivariate case:
%              m_1=multiplicity of e_1 (if dir=1)
%              m_1=multiplicity of e_2 (if dir=2)
%           - In the trivariate case:
%              m_1=multiplicity of e_1 | e_2 (if dir=1) 
%              m_1=multiplicity of e_3 (if dir=2)
%           Unnecessary if dir = 3.
%
%<Output Parameters>  
%   c   --> vector b with duplicated coefficients
%           (if b is a row vector, c is a row vector too;
%           if b is a column vector, c is a column vector too)

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

[rb,cb]=size(b);

s=max(rb,cb);

if (dir==1 | dir==2)
   d=m1;
else
   d=(s-m)/(m-1);
end
c(1:m)=b(1:m);
for i=1:d
    c(i*m+1)=c(i*m);
    c(i*m+2:i*m+m)=b(i*(m-1)+2:i*(m-1)+m);    
end
   
if cb==1
   c=c(:);
end
