function A = step3_mdds2d(k,L,n,B)
%step3_mdds2d --> Computation of differences-summations 
%                 along direction e_12=[1 1]'.
%
%<Synopsis>
%  A = step3_mdds2d(k,L,n,B)
%
%<Description>
%  To compute the Bezier net coefficients of the bivariate 
%  three-direction Box-spline with multiplicities vector nu=[k L n], 
%  we generate the mixed directions that will be used for defining the 
%  integration paths on the coefficients in B. Here, B is a 
%  bi-dimensional array with the Bezier coefficients of the bivariate 
%  three-direction Box-spline with multiplicities vector [k L n-1]. 
%
%<Input Parameters>
%   k --> nu(1) (multiplicity of direction e_1=[1 0]')
%   L --> nu(2) (multiplicity of direction e_2=[0 1]')
%   n --> nu(3) (multiplicity of direction e_12=[1 1]')
%   B --> bi-dimensional array with the Bezier coefficients of
%         the bivariate three-direction Box-spline with multiplicities
%         vector [k L n-1]
%
%<Output Parameters>  
%   A --> bi-dimensional array with the Bezier coefficients of
%         the bivariate three-direction Box-spline with multiplicities
%         vector [k L n]

%<Algorithm> 
%  First apply the shifting and subtracting procedure on the 
%  coefficients in B. Then compute the mixed directions that will be 
%  used for defining the integration paths on the new coefficients in B.
%
%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

% Box-spline degree
m=k+L+n-2;

% Shifting and subtracting procedure on the Bezier coefficients in B
[r,col]=size(B);
dB=m-1;
B=[zeros(dB,col+dB);B zeros(r,dB)]-[zeros(r,dB) B; zeros(dB,col+dB)];
[rB,colB]=size(B);

e=L+n;
t=m*k;
t1=m*n;

A=zeros(m*e+1,t+t1+1);
[rA,colA]=size(A);

ddB=dB-1;
x=e*dB+2;
y=x-1;
kk=k-1;
LL=L-1;

% Computation of the mixed directions that will be used for defining 
% the integration paths on the new coefficients in B

% Mixed directions in R
%---------------------------------
for s=1:LL
    h=0;
    sd=s*dB;
    i=rB-sd;
    xx=x-sd;
    while ((i>=1)&(xx-i)<=colB)       
          h=h+1;
          f(h)=B(i,xx-i);
          i=i-1;
    end
    w=integ_mdds(dupl_mdds(f,m,3));
    o=0;
    i=rA-s*m;
    xxx=xx+e-s;
    while ((i>=1)&(xxx-i)<=colA)       
          o=o+1;
          A(i,xxx-i)=w(o);
          i=i-1;
    end
end

for s=0:kk
    h=0;
    i=y;
    yy=x+s*dB;
    while ((i>=1)&(yy-i<=colB))       
          h=h+1;
          f(h)=B(i,yy-i);
          i=i-1;
    end
    w=integ_mdds(dupl_mdds(f,m,3));
    o=0;
    i=y+e;
    yyy=yy+e+s;
    while ((i>=1)&(yyy-i)<=colA)       
          o=o+1;
          A(i,yyy-i)=w(o);
          i=i-1;
    end
end

% Direction pattern for the generation of mixed-directions in R^2
ci=[ones(1,dB) 0];

% Mixed directions in R^2
%---------------------------------
m1=m+1;
n1=n+1;
x=t1+2;
for g=0:LL
    xx=x+g*m;
    y=n1+g;
    for r=0:ddB
        h=0;
        ii=xx+r-y;
        jj=1;
        v=m-r;
        vv=1;
        while ((ii>1)&(jj<colB))
            if (vv==m1)
                vv=1;
            end
            if (v==m1)
                v=1;
            end
            h=h+1;
            f(h)=B(ii,jj);
            ii=ii-ci(v);
            jj=jj+ci(vv);
            vv=vv+1;
            v=v+1;
        end
        f(h+1)=B(ii,jj);
        w=integ_mdds(f(1:h+1));
        i=xx+r;
        j=1;
        o=0;            
        while ((i>1)&(j<colA))
            o=o+1;
            A(i,j)=w(o);
            i=i-1;
            j=j+1;
        end
        A(i,j)=w(o+1);
    end
end    
clear f

for g=0:kk
    tt=t-g*m;
    uu=g-kk;
    for r=0:ddB
        h=0;
        ii=rB;
        jj=tt-r+uu;
        vv=1;
        v=m-r;
        while ((ii>1)&(jj<colB))
            if (vv==m1)
                vv=1;
            end
            if (v==m1)
                v=1;
            end
            h=h+1;
            f(h)=B(ii,jj);
            ii=ii-ci(vv);
            jj=jj+ci(v);
            v=v+1;
            vv=vv+1;
        end
        f(h+1)=B(ii,jj);
        w=integ_mdds(f(1:h+1));
        i=rA;
        j=tt-r;            
        o=0;
        while ((i>1)&(j<colA))
            o=o+1;            
            A(i,j)=w(o);
            i=i-1;
            j=j+1;    
        end
        A(i,j)=w(o+1);        
    end
end